# BOLT #7 types
MSG_TYPE_CHANNEL_ANNOUNCEMENT = 256
MSG_TYPE_NODE_ANNOUNCEMENT = 257
MSG_TYPE_CHANNEL_UPDATE = 258

# Core Lightning internal messages
MSG_TYPE_CHANNEL_AMOUNT = 4101
MSG_TYPE_PRIVATE_UPDATE = 4102
MSG_TYPE_DELETE_CHANNEL = 4103
MSG_TYPE_PRIVATE_CHANNEL = 4104
MSG_TYPE_ENDED = 4105
MSG_TYPE_CHANNEL_DYING = 4106

# Type name map
GOSSIP_TYPE_NAMES = {
    MSG_TYPE_CHANNEL_ANNOUNCEMENT: "channel_announcement",
    MSG_TYPE_NODE_ANNOUNCEMENT: "node_announcement",
    MSG_TYPE_CHANNEL_UPDATE: "channel_update",
    MSG_TYPE_CHANNEL_AMOUNT: "channel_amount",
    MSG_TYPE_PRIVATE_UPDATE: "private_update",
    MSG_TYPE_DELETE_CHANNEL: "delete_channel",
    MSG_TYPE_PRIVATE_CHANNEL: "private_channel",
    MSG_TYPE_ENDED: "ended",
    MSG_TYPE_CHANNEL_DYING: "channel_dying",
}

LIGHTNING_TYPES = {
    MSG_TYPE_CHANNEL_ANNOUNCEMENT,
    MSG_TYPE_NODE_ANNOUNCEMENT,
    MSG_TYPE_CHANNEL_UPDATE,
}

CORE_LIGHTNING_TYPES = {
    MSG_TYPE_CHANNEL_AMOUNT,
    MSG_TYPE_PRIVATE_UPDATE,
    MSG_TYPE_DELETE_CHANNEL,
    MSG_TYPE_PRIVATE_CHANNEL,
    MSG_TYPE_ENDED,
    MSG_TYPE_CHANNEL_DYING,
}
